package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.InitialSystemInfo;
import com.ruoyi.rocketmq.domain.vo.SystemMsgVo;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * 系统监控信息Mapper接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface InitialSystemInfoMapper 
{
    /**
     * 查询系统监控信息
     * 
     * @param id 系统监控信息主键
     * @return 系统监控信息
     */
    public InitialSystemInfo selectInitialSystemInfoById(Long id);

    /**
     * 查询系统监控信息列表
     * 
     * @param initialSystemInfo 系统监控信息
     * @return 系统监控信息集合
     */
    public List<InitialSystemInfo> selectInitialSystemInfoList(InitialSystemInfo initialSystemInfo);

    /**
     * 新增系统监控信息
     * 
     * @param initialSystemInfo 系统监控信息
     * @return 结果
     */
    public int insertInitialSystemInfo(InitialSystemInfo initialSystemInfo);

    /**
     * 修改系统监控信息
     * 
     * @param initialSystemInfo 系统监控信息
     * @return 结果
     */
    public int updateInitialSystemInfo(InitialSystemInfo initialSystemInfo);

    /**
     * 删除系统监控信息
     * 
     * @param id 系统监控信息主键
     * @return 结果
     */
    public int deleteInitialSystemInfoById(Long id);

    /**
     * 批量删除系统监控信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialSystemInfoByIds(Long[] ids);
    /**
     * 批量新增系统监控信息
     *
     * @param list 系统监控信息集合
     * @return 结果
     */
    int batchInsertInitialSystemInfo(@Param("list") List<InitialSystemInfo> list);

    SystemMsgVo getSystemMsgByClientId(String clientId);
}
